@@ -5,7 +5,7 @@
 // <Ilya.Skriblovsky@gmail.com>
 //
 
-// $Id: Main.cpp 108 2010-07-07 13:23:53Z mitrandir $
+// $Id: Main.cpp 124 2010-07-27 11:27:25Z mitrandir $
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -46,6 +46,12 @@ int main(int argc, char *argv[])
         return 1;
     }
 
+    if (! XTools::checkXRenderExtension())
+    {
+        fprintf(stderr, "XServer doesn't support XRender\n");
+        return 1;
+    }
+
     XTools::enableCompositeRedirect();
 
     Resources resources(dpy);
