@@ -5,7 +5,7 @@
 // <Ilya.Skriblovsky@gmail.com>
 //
 
-// $Id: Settings.cpp 105 2010-07-06 10:59:53Z mitrandir $
+// $Id: Settings.cpp 124 2010-07-27 11:27:25Z mitrandir $
 
 #include "Settings.h"
 
@@ -42,6 +42,8 @@ Settings::Settings()
     _borderColor = strdup("#215173");
     _borderActiveColor = strdup("#315994");
 
+    _brokenPatternFilename = strdup("/usr/share/telescope/broken-pattern.png");
+
     _borderWidth = 3;
     _textLeftMargin = 7;
     _textRightMargin = 27;
@@ -305,6 +307,11 @@ void Settings::parseOpt(const char *key, const char *value)
         free(_borderActiveColor);
         _borderActiveColor = strdup(value);
     }
+    else if (strcmp(key, "broken.pattern") == 0)
+    {
+        free(_brokenPatternFilename);
+        _brokenPatternFilename = strdup(value);
+    }
     else if (strcmp(key, "border.width") == 0)
         _borderWidth = atoi(value);
     else if (strcmp(key, "text.leftMargin") == 0)
